@@ -3,14 +3,22 @@
 from __future__ import annotations
 
 import re
+import sys
 from itertools import chain, groupby, product
-from typing import Iterator
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from collections.abc import Iterator
+
+LATEST_PYTHON_MINOR_MIN: int = 10
+LATEST_PYTHON_MINOR_MAX: int = 14
 
 
 def filter_for_env(value: str, name: str | None) -> str:
     current = (
         set(chain.from_iterable([(i for i, _ in a) for a in find_factor_groups(name)])) if name is not None else set()
     )
+    current.add(sys.platform)
     overall = []
     for factors, content in expand_factors(value):
         if factors is None:
@@ -61,12 +69,13 @@ def expand_factors(value: str) -> Iterator[tuple[list[list[tuple[str, bool]]] |
 
 def find_factor_groups(value: str) -> Iterator[list[tuple[str, bool]]]:
     """Transform '{py,!pi}-{a,b},c' to [{'py', 'a'}, {'py', 'b'}, {'pi', 'a'}, {'pi', 'b'}, {'c'}]."""
+    value = expand_ranges(value)
     for env in expand_env_with_negation(value):
         result = [name_with_negate(f) for f in env.split("-")]
         yield result
 
 
-_FACTOR_RE = re.compile(r"!?[\w._][\w._-]*")
+_FACTOR_RE = re.compile(r"(?:!?[\w._][\w._-]*|^$)")
 
 
 def expand_env_with_negation(value: str) -> Iterator[str]:
@@ -93,8 +102,34 @@ def is_negated(factor: str) -> bool:
     return factor.startswith("!")
 
 
+def expand_ranges(value: str) -> str:
+    """Expand ranges in env expressions.
+
+    Supports closed ranges ``{10-13}``, right-open ``{10-}`` (upper bound = :data:`LATEST_PYTHON_MINOR_MAX`), and
+    left-open ``{-13}`` (lower bound = :data:`LATEST_PYTHON_MINOR_MIN`).
+
+    """
+    matches = re.findall(r"((\d+)-(\d+)|(\d+)-|(?<=[{,])-(\d+)|\d+)(?:,|})", value)
+    for src, start_, end_, open_start, open_end in matches:
+        if src and start_ and end_:
+            start, end = int(start_), int(end_)
+            direction = 1 if start < end else -1
+            expansion = ",".join(str(x) for x in range(start, end + direction, direction))
+            value = value.replace(src, expansion, 1)
+        elif open_start:
+            expansion = ",".join(str(x) for x in range(int(open_start), LATEST_PYTHON_MINOR_MAX + 1))
+            value = value.replace(f"{open_start}-", expansion, 1)
+        elif open_end:
+            expansion = ",".join(str(x) for x in range(LATEST_PYTHON_MINOR_MIN, int(open_end) + 1))
+            value = value.replace(f"-{open_end}", expansion, 1)
+    return value
+
+
 __all__ = (
+    "LATEST_PYTHON_MINOR_MAX",
+    "LATEST_PYTHON_MINOR_MIN",
     "expand_factors",
+    "expand_ranges",
     "extend_factors",
     "filter_for_env",
     "find_envs",
