@@ -38,6 +38,7 @@ def test_verbose_no_test() -> None:
         "root_dir": None,
         "config_file": None,
         "result_json": None,
+        "no_capture": False,
         "command": "legacy",
         "default_runner": "virtualenv",
         "force_dep": [],
@@ -54,6 +55,7 @@ def test_verbose_no_test() -> None:
         "exit_and_dump_after": 0,
         "skip_missing_interpreters": "config",
         "skip_pkg_install": False,
+        "skip_env_install": False,
         "recreate": False,
         "no_recreate_provision": False,
         "no_test": True,
@@ -71,6 +73,7 @@ def test_verbose_no_test() -> None:
         "labels": [],
         "skip_env": "",
         "list_dependencies": is_ci(),
+        "remainder": [],
     }
 
 
@@ -110,6 +113,7 @@ def test_env_var_exhaustive_parallel_values(
         "list_envs_all": False,
         "no_recreate_pkg": False,
         "no_test": True,
+        "no_capture": False,
         "override": [Override("a=b"), Override("c=d")],
         "package_only": False,
         "parallel": 3,
@@ -124,6 +128,7 @@ def test_env_var_exhaustive_parallel_values(
         "site_packages": False,
         "skip_missing_interpreters": "config",
         "skip_pkg_install": False,
+        "skip_env_install": False,
         "verbose": 5,
         "work_dir": None,
         "root_dir": None,
@@ -133,6 +138,7 @@ def test_env_var_exhaustive_parallel_values(
         "exit_and_dump_after": 0,
         "skip_env": "",
         "list_dependencies": is_ci(),
+        "remainder": [],
     }
     assert options.parsed.verbosity == 4
     assert options.cmd_handlers == core_handlers
